@@ -90,7 +90,15 @@ for repository in `cat ${scriptDir}/../repository-list.txt` ; do
         echo "==============================================================================="
         cd $repository
 
-        if [ "$repository" == "kie-soup" ]; then
+        if [ "$repository" == "lienzo-core" ]; then
+            mvnVersionsSet
+            returnCode=$?
+
+        elif [ "$repository" == "lienzo-tests" ]; then
+            mvnVersionsSet
+            returnCode=$?
+
+        elif [ "$repository" == "kie-soup" ]; then
             mvnVersionsSet
             cd kie-soup-bom
             mvnVersionsSet
@@ -128,12 +136,19 @@ for repository in `cat ${scriptDir}/../repository-list.txt` ; do
             mvn -B -s $settingsXmlFile clean install -DskipTests
             returnCode=$?
 
-        elif [ "$repository" = "jbpm" ]; then
+        elif [ "$repository" == "drlx-parser" ];then
+            #update version in drlx-parser/pom.xml
+            cd drlx-parser
+            mvnVersionsUpdateParent
+            cd ..
+            returnCode=$?
+
+        elif [ "$repository" == "jbpm" ]; then
             mvnVersionsUpdateParentAndChildModules
             returnCode=$?
             sed -i "s/release.version=.*$/release.version=$newVersion/" jbpm-installer/src/main/resources/build.properties
 
-        elif [ "$repository" = "droolsjbpm-tools" ]; then
+        elif [ "$repository" == "droolsjbpm-tools" ]; then
             cd drools-eclipse
             mvn -B -s $settingsXmlFile -Dfull tycho-versions:set-version -DnewVersion=$newVersion
             returnCode=$?
@@ -158,6 +173,10 @@ for repository in `cat ${scriptDir}/../repository-list.txt` ; do
                 returnCode=$?
             fi
 
+        elif [ "$repository" == "optashift-employee-rostering" ]; then
+           mvnVersionsSet
+           returnCode=$?
+
         else
             mvnVersionsUpdateParentAndChildModules
             returnCode=$?
